@@ -2,6 +2,7 @@ ACCOUNT = "CoreAccount"
 ACCOUNTGROUP = "CoreAccountGroup"
 ACCOUNTROLE = "CoreAccountRole"
 ACCOUNTTOKEN = "InternalAccountToken"
+ACTION = "CoreAction"
 ARTIFACT = "CoreArtifact"
 ARTIFACTCHECK = "CoreArtifactCheck"
 ARTIFACTDEFINITION = "CoreArtifactDefinition"
@@ -21,6 +22,7 @@ DATAVALIDATOR = "CoreDataValidator"
 FILECHECK = "CoreFileCheck"
 FILETHREAD = "CoreFileThread"
 GENERICACCOUNT = "CoreGenericAccount"
+GENERATORACTION = "CoreGeneratorAction"
 GENERATORCHECK = "CoreGeneratorCheck"
 GENERATORDEFINITION = "CoreGeneratorDefinition"
 GENERATORINSTANCE = "CoreGeneratorInstance"
@@ -30,6 +32,8 @@ GENERICGROUP = "CoreGroup"
 GLOBALPERMISSION = "CoreGlobalPermission"
 GRAPHQLQUERY = "CoreGraphQLQuery"
 GRAPHQLQUERYGROUP = "CoreGraphQLQueryGroup"
+GROUPACTION = "CoreGroupAction"
+GROUPTRIGGERRULE = "CoreGroupTriggerRule"
 IPNAMESPACE = "BuiltinIPNamespace"
 IPADDRESS = "BuiltinIPAddress"
 IPADDRESSPOOL = "CoreIPAddressPool"
@@ -39,6 +43,9 @@ MENU = "CoreMenu"
 MENUITEM = "CoreMenuItem"
 NAMESPACE = "IpamNamespace"
 NODE = "CoreNode"
+NODETRIGGERRULE = "CoreNodeTriggerRule"
+NODETRIGGERATTRIBUTEMATCH = "CoreNodeTriggerAttributeMatch"
+NODETRIGGERRELATIONSHIPMATCH = "CoreNodeTriggerRelationshipMatch"
 NUMBERPOOL = "CoreNumberPool"
 LINEAGEOWNER = "LineageOwner"
 LINEAGESOURCE = "LineageSource"
@@ -51,6 +58,7 @@ PROFILE = "CoreProfile"
 PROPOSEDCHANGE = "CoreProposedChange"
 REFRESHTOKEN = "InternalRefreshToken"
 REPOSITORY = "CoreRepository"
+REPOSITORYGROUP = "CoreRepositoryGroup"
 RESOURCEPOOL = "CoreResourcePool"
 GENERICREPOSITORY = "CoreGenericRepository"
 READONLYREPOSITORY = "CoreReadOnlyRepository"
@@ -67,6 +75,7 @@ THREADCOMMENT = "CoreThreadComment"
 TRANSFORM = "CoreTransformation"
 TRANSFORMJINJA2 = "CoreTransformJinja2"
 TRANSFORMPYTHON = "CoreTransformPython"
+TRIGGERRULE = "CoreTriggerRule"
 USERVALIDATOR = "CoreUserValidator"
 VALIDATOR = "CoreValidator"
 WEBHOOK = "CoreWebhook"
