@@ -15,13 +15,13 @@ class DeleteAfterTimeQuery(Query):
         self.timestamp = timestamp
         super().__init__(**kwargs)
 
-    async def query_init(self, db: InfrahubDatabase, **kwargs: Any) -> None:
+    async def query_init(self, db: InfrahubDatabase, **kwargs: Any) -> None:  # noqa: ARG002
         self.params = {"timestamp": self.timestamp.to_string()}
         query_1 = """
         // ---------------------
         // Reset edges with to time after timestamp
         // ---------------------
-        CALL {
+        CALL () {
             OPTIONAL MATCH (p)-[r]-(q)
             WHERE r.to > $timestamp
             SET r.to = NULL
@@ -33,7 +33,7 @@ class DeleteAfterTimeQuery(Query):
             // ---------------------
             // Delete edges with from time after timestamp timestamp
             // ---------------------
-            CALL {
+            CALL () {
                 OPTIONAL MATCH (p)-[r]->(q)
                 WHERE r.from > $timestamp
                 DELETE r
@@ -49,7 +49,7 @@ class DeleteAfterTimeQuery(Query):
             // ---------------------
             // Delete edges with from time after timestamp timestamp
             // ---------------------
-            CALL {
+            CALL () {
                 OPTIONAL MATCH (p)-[r]->(q)
                 WHERE r.from > $timestamp
                 DELETE r
