@@ -16,11 +16,11 @@ from infrahub.core.node import Node
 from infrahub.core.schema import NodeSchema
 from infrahub.database import InfrahubDatabase, retry_db_transaction
 from infrahub.exceptions import NodeNotFoundError, ValidationError
-from infrahub.graphql.mutations.node_getter.interface import MutationNodeGetterInterface
 from infrahub.lock import InfrahubMultiLock, build_object_lock_name
 from infrahub.log import get_logger
 
 from .main import DeleteResult, InfrahubMutationMixin, InfrahubMutationOptions
+from .node_getter.by_default_filter import MutationNodeGetterByDefaultFilter
 
 if TYPE_CHECKING:
     from infrahub.graphql.initialization import GraphqlContext
@@ -192,21 +192,19 @@ class InfrahubIPAddressMutation(InfrahubMutationMixin, Mutation):
         )
         namespace = await address.ip_namespace.get_peer(db)
         namespace_id = await validate_namespace(db=db, branch=branch, data=data, existing_namespace_id=namespace.id)
-        try:
-            async with db.start_transaction() as dbt:
-                if lock_name := cls._get_lock_name(namespace_id, branch):
-                    async with InfrahubMultiLock(lock_registry=lock.registry, locks=[lock_name]):
-                        reconciled_address = await cls._mutate_update_object_and_reconcile(
-                            info=info, data=data, branch=branch, address=address, namespace_id=namespace_id, db=dbt
-                        )
-                else:
+
+        async with db.start_transaction() as dbt:
+            if lock_name := cls._get_lock_name(namespace_id, branch):
+                async with InfrahubMultiLock(lock_registry=lock.registry, locks=[lock_name]):
                     reconciled_address = await cls._mutate_update_object_and_reconcile(
                         info=info, data=data, branch=branch, address=address, namespace_id=namespace_id, db=dbt
                     )
+            else:
+                reconciled_address = await cls._mutate_update_object_and_reconcile(
+                    info=info, data=data, branch=branch, address=address, namespace_id=namespace_id, db=dbt
+                )
 
-                result = await cls.mutate_update_to_graphql(db=dbt, info=info, obj=reconciled_address)
-        except ValidationError as exc:
-            raise ValueError(str(exc)) from exc
+            result = await cls.mutate_update_to_graphql(db=dbt, info=info, obj=reconciled_address)
 
         return address, result
 
@@ -216,7 +214,7 @@ class InfrahubIPAddressMutation(InfrahubMutationMixin, Mutation):
         info: GraphQLResolveInfo,
         data: InputObjectType,
         branch: Branch,
-        node_getters: list[MutationNodeGetterInterface],
+        node_getter_default_filter: MutationNodeGetterByDefaultFilter,
         database: InfrahubDatabase | None = None,
     ) -> tuple[Node, Self, bool]:
         graphql_context: GraphqlContext = info.context
@@ -224,7 +222,7 @@ class InfrahubIPAddressMutation(InfrahubMutationMixin, Mutation):
 
         await validate_namespace(db=db, branch=branch, data=data)
         prefix, result, created = await super().mutate_upsert(
-            info=info, data=data, branch=branch, node_getters=node_getters, database=db
+            info=info, data=data, branch=branch, node_getter_default_filter=node_getter_default_filter, database=db
         )
 
         return prefix, result, created
@@ -258,10 +256,10 @@ class InfrahubIPPrefixMutation(InfrahubMutationMixin, Mutation):
         super().__init_subclass_with_meta__(_meta=_meta, **options)
 
     @staticmethod
-    def _get_lock_name(namespace_id: str, branch: Branch) -> str | None:
-        if not branch.is_default:
-            # Do not lock on other branches as reconciliation will be performed at least when merging in main branch.
-            return None
+    def _get_lock_name(namespace_id: str) -> str | None:
+        # IPPrefix has some cardinality-one relationships involved (parent/child/ip_address),
+        # so we need to lock on any branch to avoid creating multiple peers for these relationships
+        # during concurrent ipam reconciliations.
         return build_object_lock_name(InfrahubKind.IPPREFIX + "_" + namespace_id)
 
     @classmethod
@@ -291,12 +289,8 @@ class InfrahubIPPrefixMutation(InfrahubMutationMixin, Mutation):
         namespace_id = await validate_namespace(db=db, branch=branch, data=data)
 
         async with db.start_transaction() as dbt:
-            if lock_name := cls._get_lock_name(namespace_id, branch):
-                async with InfrahubMultiLock(lock_registry=lock.registry, locks=[lock_name]):
-                    reconciled_prefix = await cls._mutate_create_object_and_reconcile(
-                        data=data, branch=branch, db=dbt, namespace_id=namespace_id
-                    )
-            else:
+            lock_name = cls._get_lock_name(namespace_id)
+            async with InfrahubMultiLock(lock_registry=lock.registry, locks=[lock_name]):
                 reconciled_prefix = await cls._mutate_create_object_and_reconcile(
                     data=data, branch=branch, db=dbt, namespace_id=namespace_id
                 )
@@ -343,20 +337,14 @@ class InfrahubIPPrefixMutation(InfrahubMutationMixin, Mutation):
         )
         namespace = await prefix.ip_namespace.get_peer(db)
         namespace_id = await validate_namespace(db=db, branch=branch, data=data, existing_namespace_id=namespace.id)
-        try:
-            async with db.start_transaction() as dbt:
-                if lock_name := cls._get_lock_name(namespace_id, branch):
-                    async with InfrahubMultiLock(lock_registry=lock.registry, locks=[lock_name]):
-                        reconciled_prefix = await cls._mutate_update_object_and_reconcile(
-                            info=info, data=data, prefix=prefix, db=dbt, namespace_id=namespace_id, branch=branch
-                        )
-                else:
-                    reconciled_prefix = await cls._mutate_update_object_and_reconcile(
-                        info=info, data=data, prefix=prefix, db=dbt, namespace_id=namespace_id, branch=branch
-                    )
-                result = await cls.mutate_update_to_graphql(db=dbt, info=info, obj=reconciled_prefix)
-        except ValidationError as exc:
-            raise ValueError(str(exc)) from exc
+
+        async with db.start_transaction() as dbt:
+            lock_name = cls._get_lock_name(namespace_id)
+            async with InfrahubMultiLock(lock_registry=lock.registry, locks=[lock_name]):
+                reconciled_prefix = await cls._mutate_update_object_and_reconcile(
+                    info=info, data=data, prefix=prefix, db=dbt, namespace_id=namespace_id, branch=branch
+                )
+            result = await cls.mutate_update_to_graphql(db=dbt, info=info, obj=reconciled_prefix)
 
         return prefix, result
 
@@ -366,7 +354,7 @@ class InfrahubIPPrefixMutation(InfrahubMutationMixin, Mutation):
         info: GraphQLResolveInfo,
         data: InputObjectType,
         branch: Branch,
-        node_getters: list[MutationNodeGetterInterface],
+        node_getter_default_filter: MutationNodeGetterByDefaultFilter,
         database: InfrahubDatabase | None = None,
     ) -> tuple[Node, Self, bool]:
         graphql_context: GraphqlContext = info.context
@@ -374,7 +362,7 @@ class InfrahubIPPrefixMutation(InfrahubMutationMixin, Mutation):
 
         await validate_namespace(db=db, branch=branch, data=data)
         prefix, result, created = await super().mutate_upsert(
-            info=info, data=data, branch=branch, node_getters=node_getters, database=db
+            info=info, data=data, branch=branch, node_getter_default_filter=node_getter_default_filter, database=db
         )
 
         return prefix, result, created
@@ -414,21 +402,13 @@ class InfrahubIPPrefixMutation(InfrahubMutationMixin, Mutation):
 
         namespace_rels = await prefix.ip_namespace.get_relationships(db=db)
         namespace_id = namespace_rels[0].peer_id
-        try:
-            async with graphql_context.db.start_transaction() as dbt:
-                if lock_name := cls._get_lock_name(namespace_id, branch):
-                    async with InfrahubMultiLock(lock_registry=lock.registry, locks=[lock_name]):
-                        reconciled_prefix = await cls._reconcile_prefix(
-                            branch=branch, db=dbt, prefix=prefix, namespace_id=namespace_id, is_delete=True
-                        )
-                else:
-                    reconciled_prefix = await cls._reconcile_prefix(
-                        branch=branch, db=dbt, prefix=prefix, namespace_id=namespace_id, is_delete=True
-                    )
-
-        except ValidationError as exc:
-            raise ValueError(str(exc)) from exc
 
+        async with graphql_context.db.start_transaction() as dbt:
+            lock_name = cls._get_lock_name(namespace_id)
+            async with InfrahubMultiLock(lock_registry=lock.registry, locks=[lock_name]):
+                reconciled_prefix = await cls._reconcile_prefix(
+                    branch=branch, db=dbt, prefix=prefix, namespace_id=namespace_id, is_delete=True
+                )
         ok = True
 
         return DeleteResult(node=reconciled_prefix, mutation=cls(ok=ok))
