@@ -1,4 +1,5 @@
 from infrahub.permissions.backend import PermissionBackend
+from infrahub.permissions.globals import define_global_permission_from_branch
 from infrahub.permissions.local_backend import LocalPermissionBackend
 from infrahub.permissions.manager import PermissionManager
 from infrahub.permissions.report import report_schema_permissions
@@ -9,6 +10,7 @@ __all__ = [
     "LocalPermissionBackend",
     "PermissionBackend",
     "PermissionManager",
+    "define_global_permission_from_branch",
     "get_global_permission_for_kind",
     "report_schema_permissions",
 ]
